@@ -2,12 +2,13 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_athena, settings
+from moto import mock_aws, settings
 from moto.athena.models import QueryResults, athena_backends
 from moto.core import DEFAULT_ACCOUNT_ID
+from tests import aws_verified
 
 
-@mock_athena
+@mock_aws
 def test_create_work_group():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -57,35 +58,59 @@ def test_create_work_group():
     assert work_group["State"] == "ENABLED"
 
 
-@mock_athena
+@aws_verified
+@pytest.mark.aws_verified
 def test_get_primary_workgroup():
     client = boto3.client("athena", region_name="us-east-1")
-    assert len(client.list_work_groups()["WorkGroups"]) == 1
+    assert len(client.list_work_groups()["WorkGroups"]) >= 1
 
     primary = client.get_work_group(WorkGroup="primary")["WorkGroup"]
     assert primary["Name"] == "primary"
-    assert primary["Configuration"] == {}
-
-
-@mock_athena
-def test_create_and_get_workgroup():
-    client = boto3.client("athena", region_name="us-east-1")
-
-    create_basic_workgroup(client=client, name="athena_workgroup")
-
-    work_group = client.get_work_group(WorkGroup="athena_workgroup")["WorkGroup"]
-    del work_group["CreationTime"]  # Were not testing creationtime atm
-    assert work_group == {
-        "Name": "athena_workgroup",
-        "State": "ENABLED",
-        "Configuration": {
-            "ResultConfiguration": {"OutputLocation": "s3://bucket-name/prefix/"}
+    assert primary["Configuration"] == {
+        "ResultConfiguration": {},
+        "EnforceWorkGroupConfiguration": False,
+        "PublishCloudWatchMetricsEnabled": False,
+        "RequesterPaysEnabled": False,
+        "EngineVersion": {
+            "SelectedEngineVersion": "AUTO",
+            "EffectiveEngineVersion": "Athena engine version 3",
         },
-        "Description": "Test work group",
+        "EnableMinimumEncryptionConfiguration": False,
     }
 
 
-@mock_athena
+@aws_verified
+@pytest.mark.aws_verified
+def test_create_and_get_workgroup():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    wg_name = "athena_workgroup"
+    create_basic_workgroup(client=client, name=wg_name)
+
+    try:
+        work_group = client.get_work_group(WorkGroup=wg_name)["WorkGroup"]
+        del work_group["CreationTime"]  # We're not testing creationtime atm
+        assert work_group == {
+            "Name": wg_name,
+            "State": "ENABLED",
+            "Configuration": {
+                "ResultConfiguration": {"OutputLocation": "s3://bucket-name/prefix/"},
+                "EnforceWorkGroupConfiguration": True,
+                "PublishCloudWatchMetricsEnabled": False,
+                "RequesterPaysEnabled": False,
+                "EngineVersion": {
+                    "SelectedEngineVersion": "AUTO",
+                    "EffectiveEngineVersion": "Athena engine version 3",
+                },
+                "EnableMinimumEncryptionConfiguration": False,
+            },
+            "Description": "Test work group",
+        }
+    finally:
+        client.delete_work_group(WorkGroup=wg_name)
+
+
+@mock_aws
 def test_start_query_execution():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -107,7 +132,20 @@ def test_start_query_execution():
     assert response["QueryExecutionId"] != sec_response["QueryExecutionId"]
 
 
-@mock_athena
+@mock_aws
+def test_start_query_execution_without_result_configuration():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    create_basic_workgroup(client=client, name="athena_workgroup")
+    response = client.start_query_execution(
+        QueryString="query1",
+        QueryExecutionContext={"Database": "string"},
+        WorkGroup="athena_workgroup",
+    )
+    assert "QueryExecutionId" in response
+
+
+@mock_aws
 def test_start_query_validate_workgroup():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -122,12 +160,14 @@ def test_start_query_validate_workgroup():
     assert err.value.response["Error"]["Message"] == "WorkGroup does not exist"
 
 
-@mock_athena
-def test_get_query_execution():
+@mock_aws
+@pytest.mark.parametrize(
+    "location", ["s3://bucket-name/prefix/", "s3://bucket-name/prefix_wo_slash"]
+)
+def test_get_query_execution(location):
     client = boto3.client("athena", region_name="us-east-1")
 
     query = "SELECT stuff"
-    location = "s3://bucket-name/prefix/"
     database = "database"
     # Start Query
     exex_id = client.start_query_execution(
@@ -141,7 +181,11 @@ def test_get_query_execution():
     assert details["QueryExecutionId"] == exex_id
     assert details["Query"] == query
     assert details["StatementType"] == "DML"
-    assert details["ResultConfiguration"]["OutputLocation"] == location
+    result_config = details["ResultConfiguration"]
+    if location.endswith("/"):
+        assert result_config["OutputLocation"] == f"{location}{exex_id}.csv"
+    else:
+        assert result_config["OutputLocation"] == f"{location}/{exex_id}.csv"
     assert details["QueryExecutionContext"]["Database"] == database
     assert details["Status"]["State"] == "SUCCEEDED"
     assert details["Statistics"] == {
@@ -155,7 +199,23 @@ def test_get_query_execution():
     assert "WorkGroup" not in details
 
 
-@mock_athena
+@mock_aws
+def test_get_query_execution_with_execution_parameters():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    exex_id = client.start_query_execution(
+        QueryString="SELECT stuff",
+        QueryExecutionContext={"Database": "database"},
+        ResultConfiguration={"OutputLocation": "s3://bucket-name/prefix/"},
+        ExecutionParameters=["param1", "param2"],
+    )["QueryExecutionId"]
+
+    details = client.get_query_execution(QueryExecutionId=exex_id)["QueryExecution"]
+    assert details["QueryExecutionId"] == exex_id
+    assert details["ExecutionParameters"] == ["param1", "param2"]
+
+
+@mock_aws
 def test_stop_query_execution():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -177,7 +237,30 @@ def test_stop_query_execution():
     assert details["Status"]["State"] == "CANCELLED"
 
 
-@mock_athena
+@mock_aws
+def test_start_execution_with_workgroup():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    client.create_work_group(
+        Name="myworkgroup",
+        Description="Test work group",
+        Configuration={
+            "ResultConfiguration": {"OutputLocation": "s3://bucket-name/prefix/"}
+        },
+    )
+
+    exec_id = client.start_query_execution(
+        QueryString="SELECT stuff",
+        QueryExecutionContext={"Database": "database"},
+        ResultConfiguration={"OutputLocation": "s3://bucket-name/prefix/"},
+        WorkGroup="myworkgroup",
+    )["QueryExecutionId"]
+
+    execution = client.get_query_execution(QueryExecutionId=exec_id)["QueryExecution"]
+    assert execution["WorkGroup"] == "myworkgroup"
+
+
+@mock_aws
 def test_create_named_query():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -189,7 +272,7 @@ def test_create_named_query():
     assert "NamedQueryId" in res
 
 
-@mock_athena
+@mock_aws
 def test_get_named_query():
     client = boto3.client("athena", region_name="us-east-1")
     query_name = "query-name"
@@ -224,7 +307,7 @@ def create_basic_workgroup(client, name):
     )
 
 
-@mock_athena
+@mock_aws
 def test_create_data_catalog():
     client = boto3.client("athena", region_name="us-east-1")
     response = client.create_data_catalog(
@@ -257,7 +340,7 @@ def test_create_data_catalog():
     assert data_catalog["Type"] == "GLUE"
 
 
-@mock_athena
+@mock_aws
 def test_create_and_get_data_catalog():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -278,7 +361,7 @@ def test_create_and_get_data_catalog():
     }
 
 
-@mock_athena
+@mock_aws
 def test_get_query_results():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -287,7 +370,7 @@ def test_get_query_results():
     assert result["ResultSet"]["Rows"] == []
     assert result["ResultSet"]["ResultSetMetadata"]["ColumnInfo"] == []
 
-    if not settings.TEST_SERVER_MODE:
+    if settings.TEST_DECORATOR_MODE:
         backend = athena_backends[DEFAULT_ACCOUNT_ID]["us-east-1"]
         rows = [{"Data": [{"VarCharValue": ".."}]}]
         column_info = [
@@ -314,7 +397,7 @@ def test_get_query_results():
         assert result["ResultSet"]["ResultSetMetadata"]["ColumnInfo"] == column_info
 
 
-@mock_athena
+@mock_aws
 def test_get_query_results_queue():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -360,7 +443,7 @@ def test_get_query_results_queue():
         assert result["ResultSet"]["ResultSetMetadata"]["ColumnInfo"] == column_info
 
 
-@mock_athena
+@mock_aws
 def test_list_query_executions():
     client = boto3.client("athena", region_name="us-east-1")
 
@@ -378,7 +461,51 @@ def test_list_query_executions():
     assert executions["QueryExecutionIds"][0] == exec_id
 
 
-@mock_athena
+@mock_aws
+def test_list_query_executions_by_workgroup():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    create_basic_workgroup(client=client, name="athena_workgroup")
+    create_basic_workgroup(client=client, name="athena_workgroup_1")
+
+    client.start_query_execution(
+        QueryString="query1",
+        QueryExecutionContext={"Database": "string"},
+        ResultConfiguration={"OutputLocation": "string"},
+        WorkGroup="athena_workgroup",
+    )
+    exec_result = client.start_query_execution(
+        QueryString="query1",
+        QueryExecutionContext={"Database": "string"},
+        ResultConfiguration={"OutputLocation": "string"},
+        WorkGroup="athena_workgroup_1",
+    )
+    exec_id = exec_result["QueryExecutionId"]
+
+    executions = client.list_query_executions(WorkGroup="athena_workgroup_1")
+    assert len(executions["QueryExecutionIds"]) == 1
+    assert executions["QueryExecutionIds"][0] == exec_id
+
+
+@mock_aws
+def test_list_query_executions_by_workgroup_when_none_match():
+    client = boto3.client("athena", region_name="us-east-1")
+
+    create_basic_workgroup(client=client, name="athena_workgroup")
+    create_basic_workgroup(client=client, name="athena_workgroup_1")
+
+    client.start_query_execution(
+        QueryString="query1",
+        QueryExecutionContext={"Database": "string"},
+        ResultConfiguration={"OutputLocation": "string"},
+        WorkGroup="athena_workgroup",
+    )
+
+    executions = client.list_query_executions(WorkGroup="athena_workgroup_1")
+    assert len(executions["QueryExecutionIds"]) == 0
+
+
+@mock_aws
 def test_list_named_queries():
     client = boto3.client("athena", region_name="us-east-1")
     create_basic_workgroup(client=client, name="athena_workgroup")
@@ -394,7 +521,7 @@ def test_list_named_queries():
     assert len(list_primary_wg["NamedQueryIds"]) == 0
 
 
-@mock_athena
+@mock_aws
 def test_create_prepared_statement():
     client = boto3.client("athena", region_name="us-east-1")
     create_basic_workgroup(client=client, name="athena_workgroup")
@@ -408,7 +535,7 @@ def test_create_prepared_statement():
     assert metadata["RetryAttempts"] == 0
 
 
-@mock_athena
+@mock_aws
 def test_get_prepared_statement():
     client = boto3.client("athena", region_name="us-east-1")
     create_basic_workgroup(client=client, name="athena_workgroup")
@@ -421,3 +548,35 @@ def test_get_prepared_statement():
         StatementName="stmt-name", WorkGroup="athena_workgroup"
     )
     assert "PreparedStatement" in resp
+
+
+@mock_aws
+def test_get_query_runtime_statistics_no_execution_id():
+    client = boto3.client("athena", region_name="us-east-1")
+    create_basic_workgroup(client=client, name="athena_workgroup")
+
+    with pytest.raises(ClientError) as exc:
+        client.get_query_runtime_statistics(QueryExecutionId="1")
+
+    err = exc.value.response["Error"]
+    assert err["Code"] == "InvalidRequestException"
+    assert err["Message"] == "QueryExecution 1 was not found"
+
+
+@mock_aws
+def test_get_query_runtime_statistics_with_execution_id():
+    client = boto3.client("athena", region_name="us-east-1")
+    create_basic_workgroup(client=client, name="athena_workgroup")
+    response = client.start_query_execution(
+        QueryString="query1",
+        QueryExecutionContext={"Database": "string"},
+        ResultConfiguration={"OutputLocation": "string"},
+        WorkGroup="athena_workgroup",
+    )
+    assert "QueryExecutionId" in response
+
+    statistics = client.get_query_runtime_statistics(
+        QueryExecutionId=response["QueryExecutionId"]
+    )
+
+    assert "QueryRuntimeStatistics" in statistics
