@@ -189,6 +189,10 @@ def test_modify_db_cluster_manage_master_user_password(client, with_custom_kms_k
         DBClusterIdentifier=cluster_id, ManageMasterUserPassword=False
     )
 
+    retry_revert_modification_response = client.modify_db_cluster(
+        DBClusterIdentifier=cluster_id, ManageMasterUserPassword=False
+    )
+
     assert create_response["DBCluster"].get("MasterUserSecret") is None
     master_user_secret = modify_response["DBCluster"]["MasterUserSecret"]
     assert len(master_user_secret.keys()) == 3
@@ -213,6 +217,9 @@ def test_modify_db_cluster_manage_master_user_password(client, with_custom_kms_k
         == describe_response["DBClusters"][0]["MasterUserSecret"]["SecretArn"]
     )
     assert revert_modification_response["DBCluster"].get("MasterUserSecret") is None
+    assert (
+        retry_revert_modification_response["DBCluster"].get("MasterUserSecret") is None
+    )
 
 
 @pytest.mark.parametrize("with_apply_immediately", [True, False])
@@ -1830,6 +1837,104 @@ def test_failover_db_cluster(client):
     assert cluster_members[1]["IsClusterWriter"] is True
 
 
+@mock_aws
+def test_failover_db_cluster_without_target_instance_specified(client):
+    cluster_identifier = "cluster-1"
+    create_db_cluster(
+        DBClusterIdentifier=cluster_identifier,
+        Engine="aurora-postgresql",
+    )
+    create_db_instance(
+        DBInstanceIdentifier="test-instance-primary",
+        Engine="aurora-postgresql",
+        DBClusterIdentifier=cluster_identifier,
+    )
+    create_db_instance(
+        DBInstanceIdentifier="test-instance-replica",
+        Engine="aurora-postgresql",
+        DBClusterIdentifier=cluster_identifier,
+    )
+    cluster = client.describe_db_clusters(DBClusterIdentifier=cluster_identifier)[
+        "DBClusters"
+    ][0]
+    cluster_members = cluster["DBClusterMembers"]
+    assert len(cluster_members) == 2
+    assert cluster_members[0]["DBInstanceIdentifier"] == "test-instance-primary"
+    assert cluster_members[0]["IsClusterWriter"] is True
+    assert cluster_members[1]["DBInstanceIdentifier"] == "test-instance-replica"
+    assert cluster_members[1]["IsClusterWriter"] is False
+    cluster_failed_over = client.failover_db_cluster(
+        DBClusterIdentifier=cluster_identifier,
+    )["DBCluster"]
+    cluster_members = cluster_failed_over["DBClusterMembers"]
+    assert len(cluster_members) == 2
+    assert cluster_members[0]["DBInstanceIdentifier"] == "test-instance-primary"
+    assert cluster_members[0]["IsClusterWriter"] is False
+    assert cluster_members[1]["DBInstanceIdentifier"] == "test-instance-replica"
+    assert cluster_members[1]["IsClusterWriter"] is True
+
+
+@mock_aws
+def test_failover_db_cluster_with_single_instance_cluster(client):
+    cluster_identifier = "cluster-1"
+    create_db_cluster(
+        DBClusterIdentifier=cluster_identifier,
+        Engine="aurora-postgresql",
+    )
+    create_db_instance(
+        DBInstanceIdentifier="test-instance-primary",
+        Engine="aurora-postgresql",
+        DBClusterIdentifier=cluster_identifier,
+    )
+    cluster = client.describe_db_clusters(DBClusterIdentifier=cluster_identifier)[
+        "DBClusters"
+    ][0]
+    cluster_members = cluster["DBClusterMembers"]
+    assert len(cluster_members) == 1
+    assert cluster_members[0]["DBInstanceIdentifier"] == "test-instance-primary"
+    assert cluster_members[0]["IsClusterWriter"] is True
+    with pytest.raises(ClientError) as ex:
+        client.failover_db_cluster(
+            DBClusterIdentifier=cluster_identifier,
+        )
+    err = ex.value.response["Error"]
+    assert err["Code"] == "InvalidDBClusterStateFault"
+
+
+@mock_aws
+def test_failover_db_cluster_exceptions(client):
+    with pytest.raises(ClientError) as ex:
+        client.failover_db_cluster(
+            DBClusterIdentifier="non-existent-cluster",
+            TargetDBInstanceIdentifier="non-existent-instance",
+        )
+    err = ex.value.response["Error"]
+    assert err["Code"] == "InvalidParameterValue"
+    create_db_instance(
+        DBInstanceIdentifier="now-existent-instance",
+        Engine="postgres",
+    )
+    with pytest.raises(ClientError) as ex:
+        client.failover_db_cluster(
+            DBClusterIdentifier="non-existent-cluster",
+            TargetDBInstanceIdentifier="now-existent-instance",
+        )
+    err = ex.value.response["Error"]
+    assert err["Code"] == "DBClusterNotFoundFault"
+    # Real AWS seems to check for the target instance being in a valid state
+    # before checking if it is actually part of the cluster, so we can put
+    # this non-clustered instance into a stopped state to simulate the error
+    # that AWS would return for a target instance in a non-valid state.
+    client.stop_db_instance(DBInstanceIdentifier="now-existent-instance")
+    with pytest.raises(ClientError) as ex:
+        client.failover_db_cluster(
+            DBClusterIdentifier="non-existent-cluster",
+            TargetDBInstanceIdentifier="now-existent-instance",
+        )
+    err = ex.value.response["Error"]
+    assert err["Code"] == "InvalidDBInstanceState"
+
+
 @mock_aws
 def test_db_cluster_writer_promotion(client):
     client.create_db_cluster(
@@ -1868,3 +1973,36 @@ def test_db_cluster_writer_promotion(client):
         if i["IsClusterWriter"]
     )
     assert writer == "test-instance-2"
+
+
+@mock_aws
+def test_db_cluster_identifier_is_case_insensitive(client):
+    cluster = client.create_db_cluster(
+        DBClusterIdentifier="FooBar",
+        DatabaseName="db_name",
+        Engine="aurora-postgresql",
+        MasterUsername="root",
+        MasterUserPassword="password",
+    )["DBCluster"]
+    assert cluster["DBClusterIdentifier"] == "foobar"
+
+    for identifier in "foobar", "FOOBAR":
+        response = client.describe_db_clusters(DBClusterIdentifier=identifier)
+        assert response["DBClusters"][0]["DBClusterIdentifier"] == "foobar"
+
+    response = client.modify_db_cluster(
+        DBClusterIdentifier="fOObAR",
+        NewDBClusterIdentifier="XxYy",
+    )
+    assert response["DBCluster"]["DBClusterIdentifier"] == "xxyy"
+
+    instance = create_db_instance(
+        DBInstanceIdentifier="clustered-instance",
+        DBClusterIdentifier="XxYy",
+        Engine="aurora-postgresql",
+    )
+    assert instance["DBClusterIdentifier"] == "xxyy"
+    client.delete_db_instance(DBInstanceIdentifier="clustered-instance")
+
+    response = client.delete_db_cluster(DBClusterIdentifier="xXyY")
+    assert response["DBCluster"]["DBClusterIdentifier"] == "xxyy"
