@@ -636,7 +636,10 @@ def test_create_receipt_rule_set():
     with pytest.raises(ClientError) as ex:
         conn.create_receipt_rule_set(RuleSetName="testRuleSet")
 
-    assert ex.value.response["Error"]["Code"] == "RuleSetNameAlreadyExists"
+    assert ex.value.response["Error"]["Code"] == "AlreadyExists"
+    assert (
+        ex.value.response["Error"]["Message"] == "Rule set already exists: testRuleSet"
+    )
 
 
 @mock_aws
@@ -704,7 +707,8 @@ def test_create_receipt_rule():
             },
         )
 
-    assert ex.value.response["Error"]["Code"] == "RuleAlreadyExists"
+    assert ex.value.response["Error"]["Code"] == "AlreadyExists"
+    assert ex.value.response["Error"]["Message"] == "Rule already exists: testRule"
 
     with pytest.raises(ClientError) as ex:
         conn.create_receipt_rule(
@@ -736,6 +740,10 @@ def test_create_receipt_rule():
         )
 
     assert ex.value.response["Error"]["Code"] == "RuleSetDoesNotExist"
+    assert (
+        ex.value.response["Error"]["Message"]
+        == "Rule set does not exist: InvalidRuleSetaName"
+    )
 
 
 @mock_aws
@@ -897,6 +905,10 @@ def test_describe_receipt_rule():
         conn.describe_receipt_rule(RuleSetName="invalidRuleSetName", RuleName=rule_name)
 
     assert error.value.response["Error"]["Code"] == "RuleSetDoesNotExist"
+    assert (
+        error.value.response["Error"]["Message"]
+        == "Rule set does not exist: invalidRuleSetName"
+    )
 
     with pytest.raises(ClientError) as error:
         conn.describe_receipt_rule(
@@ -904,6 +916,10 @@ def test_describe_receipt_rule():
         )
 
     assert error.value.response["Error"]["Code"] == "RuleDoesNotExist"
+    assert (
+        error.value.response["Error"]["Message"]
+        == "Rule does not exist: invalidRuleName"
+    )
 
 
 @mock_aws
@@ -1177,8 +1193,7 @@ def test_create_ses_template():
         Template={
             "TemplateName": "MyTemplate",
             "SubjectPart": "Greetings, {{name}}!",
-            "TextPart": "Dear {{name}},"
-            "\r\nYour favorite animal is {{favoriteanimal}}.",
+            "TextPart": "Dear {{name}},\r\nYour favorite animal is {{favoriteanimal}}.",
             "HtmlPart": "<h1>Hello {{name}},"
             "</h1><p>Your favorite animal is {{favoriteanimal}}.</p>",
         }
@@ -1231,8 +1246,7 @@ def test_render_template():
         Template={
             "TemplateName": "MyTestTemplate",
             "SubjectPart": "Greetings, {{name}}!",
-            "TextPart": "Dear {{name}},"
-            "\r\nYour favorite animal is {{favoriteanimal}}.",
+            "TextPart": "Dear {{name}},\r\nYour favorite animal is {{favoriteanimal}}.",
             "HtmlPart": "<h1>Hello {{name}},"
             "</h1><p>Your favorite animal is {{favoriteanimal}}.</p>",
         }
@@ -1252,8 +1266,7 @@ def test_render_template():
         Template={
             "TemplateName": "MyTestTemplate1",
             "SubjectPart": "Greetings, {{name}}!",
-            "TextPart": "Dear {{name}},"
-            "\r\nYour favorite animal is {{favoriteanimal}}.",
+            "TextPart": "Dear {{name}},\r\nYour favorite animal is {{favoriteanimal}}.",
             "HtmlPart": "<h1>Hello {{name}},"
             "</h1><p>Your favorite animal is {{favoriteanimal  }}.</p>",
         }
@@ -1318,7 +1331,7 @@ def test_update_ses_template():
     template = {
         "TemplateName": "MyTemplateToUpdate",
         "SubjectPart": "Greetings, {{name}}!",
-        "TextPart": "Dear {{name}}," "\r\nYour favorite animal is {{favoriteanimal}}.",
+        "TextPart": "Dear {{name}},\r\nYour favorite animal is {{favoriteanimal}}.",
         "HtmlPart": "<h1>Hello {{name}},"
         "</h1><p>Your favorite animal is {{favoriteanimal}}.</p>",
     }
@@ -1537,3 +1550,67 @@ def test_get_identity_verification_attributes():
         attributes["VerificationAttributes"]["foo@bar.com"]["VerificationStatus"]
         == "Success"
     )
+
+
+@mock_aws
+def test_update_configuration_set_reputation_metrics():
+    conn = boto3.client("ses", region_name="us-east-1")
+
+    # Create a configuration set first
+    conn.create_configuration_set(ConfigurationSet={"Name": "test-config-set"})
+
+    # Enable reputation metrics
+    response = conn.update_configuration_set_reputation_metrics_enabled(
+        ConfigurationSetName="test-config-set", Enabled=True
+    )
+    assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+
+    # Test with non-existent configuration set
+    with pytest.raises(ClientError) as e:
+        conn.update_configuration_set_reputation_metrics_enabled(
+            ConfigurationSetName="non-existent", Enabled=True
+        )
+    assert e.value.response["Error"]["Code"] == "ConfigurationSetDoesNotExist"
+
+
+@mock_aws
+def test_get_identity_dkim_attributes():
+    conn = boto3.client("ses", region_name="us-east-1")
+
+    # Create domain identity
+    domain = "example.com"
+    conn.verify_domain_identity(Domain=domain)
+
+    # Create email identity
+    email = "test@example.com"
+    conn.verify_email_identity(EmailAddress=email)
+
+    # Test getting DKIM attributes for both domain and email
+    response = conn.get_identity_dkim_attributes(Identities=[domain, email])
+
+    # Verify response structure
+    attributes = response["DkimAttributes"]
+    assert len(attributes) == 2
+
+    # Verify domain attributes
+    domain_attrs = attributes[domain]
+    assert domain_attrs["DkimEnabled"] is True
+    assert domain_attrs["DkimVerificationStatus"] == "Success"
+    assert len(domain_attrs["DkimTokens"]) == 3
+    for token in domain_attrs["DkimTokens"]:
+        assert isinstance(token, str)
+        assert len(token) > 0
+
+    # Verify email attributes
+    email_attrs = attributes[email]
+    assert email_attrs["DkimEnabled"] is True
+    assert email_attrs["DkimVerificationStatus"] == "Success"
+    assert "DkimTokens" not in email_attrs  # Email identities don't have DKIM tokens
+
+    # Test unverified identity
+    unverified = "unverified.com"
+    response = conn.get_identity_dkim_attributes(Identities=[unverified])
+    unverified_attrs = response["DkimAttributes"][unverified]
+    assert unverified_attrs["DkimEnabled"] is True
+    assert unverified_attrs["DkimVerificationStatus"] == "NotStarted"
+    assert "DkimTokens" not in unverified_attrs
